/** @module array-to-object-keys
 */
declare module array-to-object-keys {
    /**
     * Converts an array to an object with static keys and customizable values
     * @example
     * arrayToObjectKeys(["a", "b"])
     * // {a: null, b: null}
     * @example
     * arrayToObjectKeys(["a", "b"], "value")
     * // {a: "value", b: "value"}
     * @example
     * arrayToObjectKeys(["a", "b"], (key, index) => `value for ${key} #${index + 1}`)
     * // {a: "value for a #1", b: "value for b #2"}
     * @param {string[]} array Keys for the generated object
     * @param {function(value, index)|*} [valueGenerator] Optional function that sets the object values based on key and index
     * @returns {Object<string, *>} A generated object based on the array input
     */
    function default(array: string[], valueGenerator?: ((...params: any[]) => any) | any): {
        [key: string]: any;
    };
}

